#ifndef ACL_PCI_H
    #define ACL_PCI_H
/*;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  Copyright (c) 1995-1997, ADLink Technology Inc.  All rights reserved.  ;;
;;                                                                         ;;
;;      File Name   :   ACL_PCI.H                                          ;;
;;      Purpose     :   Header file for NuDAQ PCI cards                    ;;
;;      Date        :   10/18/1997                                         ;;
;;      Revision    :   1.07                                               ;;
;;      Rev 1.06 : Add PCI-9113                                            ;;
;;      Rev 1.07 : Add PCI-9114                                            ;;
;;      Rev 1.08 : Modify PCI-9118                                         ;;
;;      Date        :   11/10/1999                                         ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;*/

#ifdef __cplusplus
extern "C" {
#endif

/****************************************************************************/
/*      Typedef  Definitions                                                                                                */
/****************************************************************************/

typedef unsigned char       U8;
typedef short               I16;
typedef unsigned short      U16;
typedef long                I32;
typedef unsigned long       U32;
typedef float               F32;
typedef double              F64;
typedef char                Boolean;

enum {
    PCI_CARD1,
    PCI_CARD2,
    PCI_CARD3,
    PCI_CARD4,
    PCI_CARD5,
    PCI_CARD6,
    PCI_CARD7,
    PCI_CARD8,
    PCI_CARD9,
    PCI_CARD10,
    PCI_CARD11,
    PCI_CARD12,
    MAX_PCI_CARDS
};

typedef struct {
    U16 baseAddr[MAX_PCI_CARDS];
    U16 irqNo[MAX_PCI_CARDS];
} PCI_INFO;


/****************************************************************************/
/*      Constant Definitions                                                */
/****************************************************************************/
/*      PCI-7250 Constant Definitions                                       */
/****************************************************************************/
#define         DO_PORT0       0x00 /* For PCI-7250 Board              */
#define         DO_PORT1       0x01 /* For PCI-7251 Expansion Board #1 */
#define         DO_PORT2       0x02 /* For PCI-7251 Expansion Board #2 */
#define         DO_PORT3       0x03 /* For PCI-7251 Expansion Board #3 */

#define         DI_PORT0       0x00 /* For PCI-7250 Board              */
#define         DI_PORT1       0x01 /* For PCI-7251 Expansion Board #1 */
#define         DI_PORT2       0x02 /* For PCI-7251 Expansion Board #2 */
#define         DI_PORT3       0x03 /* For PCI-7251 Expansion Board #3 */

#define         PCI_7251_EX1   0x01 /* For PCI-7251 Board #1           */
#define         PCI_7251_EX2   0x02 /* For PCI-7251 Board #2           */
#define         PCI_7251_EX3   0x03 /* For PCI-7251 Board #3           */

#define         PCI_7251_EXIST      1
#define         PCI_7251_NOT_EXIST  0


/****************************************************************************/
/*      PCI-7248, PCI-7296 Constant Definitions                             */
/****************************************************************************/
/*----- Parameters used for Interrupt Control ------------------------------*/
#define         INT1_OFF        0x00
#define         INT1_P1C0       0x01
#define         INT1_P1C3C0     0x02
#define         INT1_EVENT_IRQ  0x03

#define         INT2_OFF        0x00
#define         INT2_P2C0       0x04
#define         INT2_P2C3C0     0x08
#define         INT2_TIMER_IRQ  0x0C

/*----- Parameters used for Event Counter Edge Control ---------------------*/
#define         EDGE_L2H        0x00
#define         EDGE_H2L        0x01

//DIO Port Direction
#define         INPUT_PORT      1
#define         OUTPUT_PORT     2

/*----- PCI-7248, PCI-7296 Channel Number Definition ----------------------*/
#define         PCI_CH0         0x00 /* Channel 0                          */
#define         PCI_CH1         0x01 /* Channel 1                          */
#define         PCI_CH2         0x02 /* Channel 2   only PCI-7296          */
#define         PCI_CH3         0x03 /* Channel 3   only PCI-7296          */

/*  PORT direction definition           PORT_A   PORT_CU   PORT_B  PORT_CL */
#define         PORT_OOOO       0x00 /*  OUT       OUT      OUT      OUT   */
#define         PORT_OOOI       0x01 /*  OUT       OUT      OUT      IN    */
#define         PORT_OOIO       0x02 /*  OUT       OUT      IN       OUT   */
#define         PORT_OOII       0x03 /*  OUT       OUT      IN       IN    */
#define         PORT_OIOO       0x04 /*  OUT       IN       OUT      OUT   */
#define         PORT_OIOI       0x05 /*  OUT       IN       OUT      IN    */
#define         PORT_OIIO       0x06 /*  OUT       IN       IN       OUT   */
#define         PORT_OIII       0x07 /*  OUT       IN       IN       IN    */

#define         PORT_IOOO       0x08 /*  IN        OUT      OUT      OUT   */
#define         PORT_IOOI       0x09 /*  IN        OUT      OUT      IN    */
#define         PORT_IOIO       0x0A /*  IN        OUT      IN       OUT   */
#define         PORT_IOII       0x0B /*  IN        OUT      IN       IN    */
#define         PORT_IIOO       0x0C /*  IN        IN       OUT      OUT   */
#define         PORT_IIOI       0x0D /*  IN        IN       OUT      IN    */
#define         PORT_IIIO       0x0E /*  IN        IN       IN       OUT   */
#define         PORT_IIII       0x0F /*  IN        IN       IN       IN    */


/*---- Channel PORT  definition -------------------------------------------*/
#define         PCI_PORTA       0x00 /* PORT-A                  */
#define         PCI_PORTB       0x01 /* PORT-A                  */
#define         PCI_PORTC       0x02 /* PORT-A                  */
#define         PCI_PORTCU      0x03 /* PORT-A                  */
#define         PCI_PORTCL      0x04 /* PORT-A                  */


#define         PCI_CH0_PA      0x00 /* Channel 0, PORT-A       */
#define         PCI_CH0_PB      0x01 /* Channel 0, PORT-B       */
#define         PCI_CH0_PC      0x02 /* Channel 0, PORT-C       */
#define         PCI_CH0_PCU     0x03 /* Channel 0, PORT-C Upper */
#define         PCI_CH0_PCL     0x04 /* Channel 0, PORT-A Lower */
#define         PCI_CH0_PAE     0x0A /* cPCI-7249 */
#define         PCI_CH0_PBE     0x0B /* cPCI-7249 */
#define         PCI_CH0_PCE     0x0C /* cPCI-7249 */


#define         PCI_CH1_PA      0x05 /* Channel 1, PORT-A       */
#define         PCI_CH1_PB      0x06 /* Channel 1, PORT-B       */
#define         PCI_CH1_PC      0x07 /* Channel 1, PORT-C       */
#define         PCI_CH1_PCU     0x08 /* Channel 1, PORT-C Upper */
#define         PCI_CH1_PCL     0x09 /* Channel 1, PORT-A Lower */
#define         PCI_CH1_PAE     0x0F /* cPCI-7249 */
#define         PCI_CH1_PBE     0x10 /* cPCI-7249 */
#define         PCI_CH1_PCE     0x11 /* cPCI-7249 */


#define         PCI_CH2_PA      0x0A /* Channel 2, PORT-A       */
#define         PCI_CH2_PB      0x0B /* Channel 2, PORT-B       */
#define         PCI_CH2_PC      0x0C /* Channel 2, PORT-C       */
#define         PCI_CH2_PCU     0x0D /* Channel 2, PORT-C Upper */
#define         PCI_CH2_PCL     0x0E /* Channel 2, PORT-A Lower */

#define         PCI_CH3_PA      0x0F /* Channel 3, PORT-A       */
#define         PCI_CH3_PB      0x10 /* Channel 3, PORT-B       */
#define         PCI_CH3_PC      0x11 /* Channel 3, PORT-C       */
#define         PCI_CH3_PCU     0x12 /* Channel 3, PORT-C Upper */
#define         PCI_CH3_PCL     0x13 /* Channel 3, PORT-A Lower */

/*------------------ For 7396 ----------------------------------------------*/
#define    P1WR        0
#define    P1RD        1
#define    E_P1RD      2
#define    P1AWR       3
#define    P1ARD       4
#define    P1BWR       6
#define    P1BRD       7
#define    P1CWR       9
#define    P1CRD       10
#define    P2WR        12
#define    P2RD        13
#define    E_P2RD      14
#define    P2AWR       15
#define    P2ARD       16
#define    P2BWR       18
#define    P2BRD       19
#define    P2CWR       21
#define    P2CRD       22
#define    P3WR        24
#define    P3RD        25
#define    E_P3RD      26
#define    P3AWR       27
#define    P3ARD       28
#define    P3BWR       30
#define    P3BRD       31
#define    P3CWR       33
#define    P3CRD       34
#define    P4WR        36
#define    P4RD        37
#define    E_P4RD      38
#define    P4AWR       39
#define    P4ARD       40
#define    P4BWR       42
#define    P4BRD       43
#define    P4CWR       45
#define    P4CRD       46


#define    P1_A      0
#define    P1_B      1
#define    P1_C      2
#define    P1_ABC    3
#define    P2_A      4
#define    P2_B      5
#define    P2_C      6
#define    P2_ABC    7
#define    P3_A      8
#define    P3_B      9
#define    P3_C      10
#define    P3_ABC    11
#define    P4_A      12
#define    P4_B      13
#define    P4_C      14
#define    P4_ABC    15

/*----- Parameters used for 7348/96 Interrupt Control Port -------------------------*/
#define    COSIRQ1         0x00
#define    P1C0            0x01
#define    P1C3            0x02
#define    EVENTIRQ        0x03
#define    DIS_INT1        4
#define    COSIRQ2         0x00
#define    P2C0            0x01
#define    P2C3            0x02
#define    TIMERIRQ        0x03
#define    DIS_INT2        4
/*----------------------------COS IRQ-----------------------------------------------*/
#define    ENABLE          1
#define    DISABLE         0


/****************************************************************************/
/*      PCI-9111 Constant Definitions                                       */
/****************************************************************************/
#define         PCI_9111_INIT_OK        0x00            //??
#define         PCI_9111_INIT_ERROR     0x01            //??

/*----- Possiable constant for _9111_Set_EDO_Function() -------------------*/
#define         EDO_INPUT       1
#define         EDO_OUT_EDO     2
#define         EDO_OUT_CHN     3

/*---------------------------- for AD mode control register value ---------*/
#define         A_9111_AD_PreTrg_ON    0x08    /* external A/D pre-trigger ON  */
#define         A_9111_AD_PreTrg_OFF   0x00
#define         A_9111_AD_External_SRC 0x04    /* external A/D trigger source  */
#define         A_9111_AD_Internal_SRC 0x00    /* internal A/D trigger source  */
#define         A_9111_AD_TimerTrig    0x02    /* internal timer pacer trigger */
#define         A_9111_AD_SoftTrig     0x00    /* software trigger             */
#define         A_9111_AD_AutoScan     0x01    /* auto scan cahnnel            */

/*---------------------------- for AD Status ------------------------------*/
#define         ADSTS_BUSY      0x08    // the 4th bit is AD Busy       , PCI-9111, PCI-9113
#define         ADSTS_FF_FF     0x04    // the 3rd bit is FIFO Full     , PCI-9111, PCI-9113
#define         ADSTS_FF_HF     0x02    // the 2nd bit is FIFO Half Full, PCI-9111, PCI-9113
#define         ADSTS_FF_EF     0x01    // the 1st bit is FIFO Empty    , PCI-9111, PCI-9113

/*---------------------------- for Int Modes setting  ---------------------*/
#define         INT1_Disable     0
#define         INT1_AD_EOC      1      // INT1 : AD EOC             , PCI-9111, PCI-9113
#define         INT1_AD_FFHF     2      // INT1 : AD FIFO Half Full  , PCI-9111, PCI-9113
#define         INT2_Disable     0
#define         INT2_Pacer       1      // INT2 : Pacer Timer Int    , PCI-9111, PCI-9113
#define         INT2_Extint      2      // INT2 : External Int Source, PCI-9111 only

/*---------------------------- Define AD Statuses -------------------------*/
#ifndef _AD_INT_STATUS
    #define _AD_INT_STATUS              // AD Interrupt State Control
                                        // For PCI-9111, PCI-9113
        #define AD_INT_INIT        0
        #define AD_INT_RUN         1
        #define AD_INT_STOP        2
        #define AD_FFHF_INT_RUN    3
        #define AD_FFHF_BLOCK_FULL 4
        #define AD_FFHF_INT_STOP   5
#endif


/****************************************************************************/
/*      PCI-9113 Constant Definitions                                       */
/****************************************************************************/
/*---------------------------- for AD mode control register value ---------*/
#define         A_9113_AD_FIFO_ENABLE  0x00
#define         A_9113_AD_FIFO_DISABLE 0x08
#define         A_9113_AD_TimerTrig    0x02    /* internal timer pacer trigger */
#define         A_9113_AD_SoftTrig     0x00    /* software trigger             */
#define         A_9113_AD_AutoScan     0x01    /* auto scan cahnnel            */


/****************************************************************************/
/*      PCI-9114 Constant Definitions                                       */
/****************************************************************************/
/*---------------------------- for AD mode control register value ---------*/
#define         A_9114_AD_FIFO_ENABLE  0x00
#define         A_9114_AD_FIFO_DISABLE 0x08
#define         A_9114_AD_TimerTrig    0x02    /* internal timer pacer trigger */
#define         A_9114_AD_SoftTrig     0x00    /* software trigger             */
#define         A_9114_AD_AutoScan     0x01    /* auto scan cahnnel            */



/****************************************************************************/
/*      PCI-9118 Constant Definitions                                       */
/****************************************************************************/
/*---------------------------------------------- for AD mode ---------------*/
#define         A_9118_AD_DMA          0x01
#define         A_9118_AD_INT          0x02
#define         A_9118_AD_TimerTrig    0x04
#define         A_9118_AD_SoftTrig     0x00
/*--------------------------- for AD clock source ------------------------*/
#define  A_9118_AD_IntSrc       0
#define  A_9118_AD_ExtSrc       1

#define A_9118_AD_MODE_0   (9118_AD_SoftTrig)               /* Software Trig, Software Polling */
#define A_9118_AD_MODE_1   (9118_AD_TimerTrig+9118_AD_INT)  /* Timer    Trig, Int transfer     */
#define A_9118_AD_MODE_2   (9118_AD_TimerTrig+9118_AD_DMA)  /* Timer    Trig, DMA Transfer     */
#define A_9118_AD_MODE_3   (9118_AD_ExtSrc+9118_AD_SoftTrig)/* External Trig, Software Polling */
#define A_9118_AD_MODE_4   (9118_AD_ExtSrc+9118_AD_INT)     /* External Trig, Int transfer     */
#define A_9118_AD_MODE_5   (9118_AD_ExtSrc+9118_AD_DMA)     /* External Trig, DMA Transfer     */

/*
;;-------------------------------------------------------------------------
;;      General Purpose Constant Definitions
;;      It can be used for all cards.
;;-------------------------------------------------------------------------
*/
/*---------------------------------------------- for AD status--------------*/
#ifndef _AD_DMA_STATUS
#define _AD_DMA_STATUS
#define         AD_DMA_STOP     0       /* for AD_DMA status */
#define         AD_DMA_RUN      1
#endif

/*--------------------------- for DA Channel -----------------------------*/
#ifndef _DA_CHANNEL
#define _DA_CHANNEL                      /* possible da_ch_no of DA */
#define         DA_CH_1         0
#define         DA_CH_2         1
#endif
/*--------------------------- for AD Channel -----------------------------*/
#ifndef _AD_CHANNEL
#define _AD_CHANNEL
#define         AD_CH_0         0
#define         AD_CH_1         1
#define         AD_CH_2         2
#define         AD_CH_3         3
#define         AD_CH_4         4
#define         AD_CH_5         5
#define         AD_CH_6         6
#define         AD_CH_7         7
#define         AD_CH_8         8
#define         AD_CH_9         9
#define         AD_CH_10        10
#define         AD_CH_11        11
#define         AD_CH_12        12
#define         AD_CH_13        13
#define         AD_CH_14        14
#define         AD_CH_15        15
#define         AD_CH_16        16
#define         AD_CH_17        17
#define         AD_CH_18        18
#define         AD_CH_19        19
#define         AD_CH_20        20
#define         AD_CH_21        21
#define         AD_CH_22        22
#define         AD_CH_23        23
#define         AD_CH_24        24
#define         AD_CH_25        25
#define         AD_CH_26        26
#define         AD_CH_27        27
#define         AD_CH_28        28
#define         AD_CH_29        29
#define         AD_CH_30        30
#define         AD_CH_31        31
#endif
/*
;;-------------------------------------------------------------------------
;;      Constant Definitions for AD Range Control
;;-------------------------------------------------------------------------
*/
#define AD_B_10_V       1       // Bipolar +/-  10V    , for PCI-9111, PCI-9118 , PCI-9113, PCI-9114            _9114_AD_Set_Range2( cno  ,  i );
#define AD_B_5_V        2       // Bipolar +/-  5V     , for PCI-9111, PCI-9118 , PCI-9114
#define AD_B_2_5_V      3       // Bipolar +/-  2.5V   , for PCI-9111, PCI-9118
#define AD_B_1_25_V     4       // Bipolar +/-  1.25V  , for PCI-9111, PCI-9118
#define AD_B_0_625_V    5       // Bipolar +/-  0.625V , for PCI-9111, PCI-9118
#define AD_B_0_3125_V   6       // Bipolar +/-  0.3125V
#define AD_B_0_5_V      7       // Bipolar +/-  0.5V              , PCI-9114
#define AD_B_0_05_V     8       // Bipolar +/-  0.05V             , PCI-9114
#define AD_B_0_005_V    9       // Bipolar +/-  0.005V
#define AD_B_1_V       10       // Bipolar +/-  1V     , PCI-9113 , PCI-9114
#define AD_B_0_1_V     11       // Bipolar +/-  0.1V   , PCI-9113 , PCI-9114
#define AD_B_0_01_V    12       // Bipolar +/-  0.01V  , PCI-9113 , PCI-9114
#define AD_U_20_V      13       // Unipolar 0 ~ 20V
#define AD_U_10_V      14       // Unipolar 0 ~ 10V    , for PCI-9118
#define AD_U_5_V       15       // Unipolar 0 ~ 5V     , for PCI-9118
#define AD_U_2_5_V     16       // Unipolar 0 ~ 2.5V   , for PCI-9118
#define AD_U_1_25_V    17       // Unipolar 0 ~ 1.25V  , for PCI-9118
#define AD_U_1_V       18       // Unipolar 0 ~ 1V     , PCI-9113
#define AD_U_0_1_V     19       // Unipolar 0 ~ 0.1V   , PCI-9113
#define AD_U_0_01_V    20       // Unipolar 0 ~ 0.01V  , PCI-9113

#define AD_B_2_V       21       // Bipolar +/-  2.0V   , for PCI-9114
#define AD_B_0_2_V     22       // Bipolar +/-  0.2V   , for PCI-9114
#define AD_B_0_02_V    23       // Bipolar +/-  0.02V  , for PCI-9114

#define AD_B_0_001_v   21       // Bipolar +/-  0.001V; for PCI-9118HG   
#define AD_U_0_001_v   22       // Unipolar 0 ~ 0.001V; for PCI-9118HG   

/*--------------------------- for DI Port --------------------------------*/
#ifndef _DI_PORT
#define _DI_PORT
#define         DI_LO_BYTE      0       /* for port_no of DI */
#define         DI_HI_BYTE      1       /* for port_no of DI */
#define         DO_LO_BYTE      0       /* for port_no of DO */
#define         DO_HI_BYTE      1       /* for port_no of DO */
#endif

/*--------------------------- for 8254 Timer / Counter Mode Definitions -*/
#define         TIMER_MODE0     0       /* Timer : Terminal Count       */
#define         TIMER_MODE1     1       /* Timer : Programmer One-shot  */
#define         TIMER_MODE2     2       /* Timer : Frq.  Generator      */
#define         TIMER_MODE3     3       /* Timer : Square Wave Generator*/
#define         TIMER_MODE4     4       /* Timer : Counter, Soft Trigger*/
#define         TIMER_MODE5     5       /* Timer : Counter, Hard Trigger*/

/*--------------------------- AD Input Mode -----------------------------*/
#define         SINGLE_ENDED    0
#define         DIFFERENTIAL    1

/*------------------------------ For 6208 -------------------------------*/
#define HIBYTE(ax) (ax >> 8)
#define LOBYTE(ax) (ax & 0xff)

/*----- Parameters used for I to V Control ---------------------------------*/
#define         I_0to20mA       0       // 0~20 mA
#define         I_5to25mA       1       // 5~25 mA
#define         I_0to16mA       2       // 0~16 mA
#define         I_4to20mA       3       // 4~20 mA

/*----- Retuen Values of the PCI-6208 Functions  ---------------------------*/
#define         PCI_6208_INIT_OK         0x6208
#define         PCI_6208_INIT_ERROR      0x0000

/*---------------------- For 7200 -------------- for card number -----------*/
#ifndef _CARD_NUMBER
#define _CARD_NUMBER
#define         PCI_MAXCARDS    4
#define         CARD_1          0       /* possible value of card_number */
#define         CARD_2          1
#define         CARD_3          2
#define         CARD_4          3
#endif

/*---------------------------------------------- for DI mode ----------*/
#define DI_MODE_0       0       /* internal timer pacer (timer 0) */
#define DI_MODE_1       1       /* external rising edge INREQ */
#define DI_MODE_2       2       /* external falling edge INREQ */
#define DI_MODE_3       3       /* INREQ/INACK handshaking */

#define DI_DMA_STOP     0       /* DI DMA completed */
#define DI_DMA_RUN      1       /* DI DMA running   */

#define DI_WAITING      1       /* DI DMA mode for waiting trigger    */
#define DI_NONWAITING   0       /* DI DMA mode for no waiting trigger */
#define DI_RISING       1       /* waiting for rising edge trigger    */
#define DI_FALLING      0       /* waiting for falling edge trigger   */

/*---------------------------------------------- for DO mode ----------*/
#define DO_MODE_0       0       /* internal timer pacer (timer 1) */
#define DO_MODE_1       1       /* internal timer pacer with OUTREQ enable */
#define DO_MODE_2       2       /* OUTREQ/OUTACK handshaking */

#define DO_DMA_STOP     0       /* DO DMA completed */
#define DO_DMA_RUN      1       /* DO DMA running   */

/*---------------------------------------------- for TIMER -----------------*/

#define         TIMER_CASCADE     1     /* c0 & c2 or c1 & c2 CASCADE  */
#define         TIMER_NONCASCADE  0     /* c0 & c2 or c1 & c2 non-CASCADE */


/****************************************************************************/
/*      Functions Declarations                                              */
/****************************************************************************/

/*------------------- For 6208 ----------------- Initial, Reset ------------*/
extern U16  _6208_Initial(U16 *existCards, PCI_INFO *pciInfo);
extern void _6208_Software_Reset(U16 cardNo);

/*---------------------------------------------- 6208 DA -------------------*/
extern U16  _6208_DA      (U16 cardNo, U16 chn, I16  DAData      );
extern U16  _6208_Get_DA_Status (U16 cardNo  );

extern U16  _6208_DI      (U16 cardNo, U16 *DIData );
extern U16  _6208_DO      (U16 cardNo, U16  DOData );
extern U16  _6208_I2V_Control (U16 cardNo, U16  ctrl  );           

/*----------------------------------------- 6308 Initial, Reset ------------*/
extern U16  _6308_Initial(U16 *existCards, PCI_INFO *pciInfo);
extern void _6308_Software_Reset(U16 cardNo);

/*---------------------------------------------- 6308 DA -------------------*/
extern U16  _6308_DA      (U16 cardNo, U16 chn, I16  DAData      );
extern U16  _6308_DA_0_3 (U16 cardNo, I16 DA0_Data, I16 DA1_Data, I16 DA2_Data, I16 DA3_Data);
extern U16  _6308_DA_4_7 (U16 cardNo, I16 DA4_Data, I16 DA5_Data, I16 DA6_Data, I16 DA7_Data);
extern U16  _6308_Get_DA_Status (U16 cardNo);

extern U16  _6308_DI      (U16 cardNo, U16 *DIData);
extern U16  _6308_DO      (U16 cardNo, U16  DOData);
extern U16  _6308_RD_DO   (U16 cardNo ,U16 *DOData );
extern U16  _6308_I2V_Control (U16 cardNo, U16  ctrl);

/************************************************************************/
/* Functions Decalerations  For 7200                                    */
/************************************************************************/
extern int _7200_Initial(U8 card_number, U16 *base_address, U8 *irq_no );
extern int _7200_Exit(U8 card_number);
extern int _7200_Switch_Card_No(U8 card_number );

extern int _7200_DI(U32 *di_data);
extern int _7200_DI_Channel(U8 di_ch_no, Boolean *di_data);

extern int _7200_DO(U32 do_data);
extern int _7200_DO_Channel(U8 do_ch_no, Boolean do_data);

//added for cPCI-7200
extern int _7200_AUX_DI(U32 *aux_di);
extern int _7200_AUX_DI_Channel(U8 di_ch_no, Boolean *aux_data);
extern int _7200_AUX_DO(U32 do_data);
extern int _7200_AUX_DO_Channel(U8 do_ch_no, Boolean do_data);

extern int _7200_DI_DMA_Start(U8 di_mode, U32 count, U32 *buff, Boolean wait_trig, U8 polarity,
           Boolean clear_fifo, Boolean disable_di); //modified
extern int _7200_DI_DMA_Status(U8 *status, U32 *count);
extern int _7200_DI_DMA_Stop(U32 *count);

extern int _7200_DblBufferMode(Boolean db_flag);
extern int _7200_CheckHalfReady(Boolean *half_ready);
extern int _7200_DblBufferTransfer(U32 far *user_buffer);
extern int _7200_GetOverrunStatus(U32 *overrun_cnt);

extern int _7200_DO_DMA_Stop(U32 *count);
extern int _7200_DO_DMA_Start(U8 do_mode, U32 count, U32 *buff, Boolean repeat_flag);
extern int _7200_DO_DMA_Status(U8 *status, U32 *count);

extern int _7200_DI_Timer(U16 c0, U16 c2, Boolean cascade_flag);
extern int _7200_DO_Timer(U16 c1, U16 c2, Boolean cascade_flag);


/****************************************************************************/
/*      Functions Declerations of PCI-7230                                  */
/****************************************************************************/
extern U16  _7230_Initial(U16 *existCards, PCI_INFO *pciInfo);
extern U16  _7230_DO( U16 cardNo, U16  doData);
extern U16  _7230_DI( U16 cardNo, U16 *diData);

extern void _7230_Set_INT_Control(U16 cardNo, U16 int1Flag, U16 int2Flag);
extern void _7230_Set_INT_Polarity( U16 cardNo, U16 int1pol, U16 int2pol );
extern void _7230_Get_IRQ_Status(U16 cardNo,U16 *int1Status, U16 *int2Status);
extern void _7230_Get_IRQ_Channel(U16 cardNo, U16 *irq_no );
extern void _7230_CLR_IRQ( U16 cardNo );
extern void _7230_Software_Reset(U16 cardNo);

/*--------------- 7233 function declaration --------------------------------*/
extern U16  _7233_Initial(U16 *existCards, PCI_INFO *info);
extern U16  _7233_DI(U16 cardNo, U32 *diData);
extern void _7233_Set_INT_Control(U16 cardNo, U16 int1Flag,  U16 int2Flag);
extern void _7233_Get_IRQ_Status(U16 cardNo, U16 *int1Status, U16 *int2Status);
extern void _7233_CLR_IRQ(U16 cardNo);


/****************************************************************************/
/*      Functions Declerations of PCI-7234                                  */
/****************************************************************************/
extern U16  _7234_Initial(U16 *existCards, PCI_INFO *pciInfo);
extern void _7234_Software_Reset(U16 cardNo);
extern U16  _7234_DO( U16 cardNo, U32  doData);

/****************************************************************************/
/*      Functions Declerations of PCI-7250 cPCI-7252                        */
/****************************************************************************/
extern U16  _7250_Initial(U16 *existCards, PCI_INFO *pciInfo);
extern U16  _7250_DO(U16 cardNo, U16 doChannelNo, U8 doData);
extern U16  _7250_DO_Read_Back(U16 cardNo, U16 doChannelNo,U8 *doReadBackData);
extern U16  _7250_DI(U16 cardNo, U16 diChannelNo, U8 *diData);
extern U16  _7251_Check_Exist(U16 cardNo, U16 extensionBoardNo);

extern void _7250_Set_INT_Control(U16 cardNo, U16 int1Flag, U16 int2Flag);
extern void _7250_Get_IRQ_Status(U16 cardNo, U16 *int1Status, U16 *int2Status);
extern void _7250_CLR_IRQ(U16 cardNo);
extern void _7250_Software_Reset(U16 cardNo);

extern U16  _7252_Initial(U16 *existCards, PCI_INFO *pciInfo);
extern U16  _7252_DO(U16 cardNo, U16 doData);
extern U16  _7252_ReadRelay(U16 cardNo ,U16 *didata);
extern U16  _7252_DI(U16 cardNo, U16 *diData);
extern void _7252_Software_Reset(U16 cardNo );
extern void _7252_CLR_IRQ(U16 cardNo);
extern void _7252_Set_INT_Control(U16 cardNo, U16 int1Flag,  U16 int2Flag);
/****************************************************************************/
/*      Functions Declerations of PCI-7248                                  */
/****************************************************************************/
extern U16  _7248_Initial(U16 *existCards, PCI_INFO *pciInfo);
extern U16  _7248_DI(U16 cardNo, U16 channelPort, U8 *inData);
extern U16  _7248_DO(U16 cardNo, U16 channelPort, U8 outData);
extern U16  _7248_Config_Channel(U16 cardNo, U16 channelNo, U16 ctrlValue);
extern U16  _7248_Config_Port(U16 cardNo, U16 channelPort, U16 direction);
extern void _7248_Set_INT_Control(U16 cardNo, U16 ctrlValue);
extern void _7248_Timer_Start(U16 cardNo, U16 timer0Mode, U16 c0);
extern void _7248_Timer_Read(U16 cardNo, U16 *counterValue);
extern void _7248_Timer_Stop(U16 cardNo, U16 *counterValue);
extern void _7248_Cascaded_Timer(U16 cardNo, U16 c1, U16 c2);
extern void _7248_Get_IRQ_Status(U16 cardNo, U16 *int1Status, U16 *int2Status);
extern void _7248_CLR_IRQ(U16 cardNo);
extern void _7248_Software_Reset(U16 cardNo);
/*-------------------------------- For 7249 ---------------------------------*/
extern U16  _7249_Initial(U16 *existCards, PCI_INFO *pciInfo);
extern U16  _7249_DI(U16 cardNo, U16 channelPort, U16 *inData);
extern U16  _7249_DO(U16 cardNo, U16 channelPort, U16 outData);
extern U16  _7249_Config_Channel(U16 cardNo, U16 channelNo, U16 ctrlValue);
extern U16  _7249_Config_Port(U16 cardNo, U16 channelPort, U16 direction);
extern void _7249_Set_INT_Control(U16 cardNo, U16 ctrlValue);
extern void _7249_Timer_Start(U16 cardNo, U16 timer0Mode, U16 c0);
extern void _7249_Timer_Read(U16 cardNo, U16 *counterValue);
extern void _7249_Timer_Stop(U16 cardNo, U16 *counterValue);
extern void _7249_Cascaded_Timer(U16 cardNo, U16 c1, U16 c2);
extern void _7249_Get_IRQ_Status(U16 cardNo, U16 *int1Status, U16 *int2Status);
extern void _7249_CLR_IRQ(U16 cardNo);
extern void _7249_Software_Reset(U16 cardNo);
/*---------------------------------------------------------------------------*/

/****************************************************************************/
/*      Functions Declerations of PCI-7296                                  */
/****************************************************************************/
extern U16  _7296_Initial(U16 *existCards, PCI_INFO *pciInfo);
extern U16  _7296_DI(U16 cardNo, U16 channelPort, U8 *inData);
extern U16  _7296_DO(U16 cardNo, U16 channelPort, U8 outData);
extern U16  _7296_Config_Channel(U16 cardNo, U16 channelNo, U16 ctrlValue);
extern U16  _7296_Config_Port(U16 cardNo, U16 channelPort, U16 direction);
extern void _7296_Set_INT_Control(U16 cardNo, U16 ctrlValue);
extern void _7296_Timer_Start(U16 cardNo, U16 timer0Mode, U16 c0);
extern void _7296_Timer_Read(U16 cardNo, U16 *counterValue);
extern void _7296_Timer_Stop(U16 cardNo, U16 *counterValue);
extern void _7296_Cascaded_Timer(U16 cardNo, U16 c1, U16 c2);
extern void _7296_Get_IRQ_Status(U16 cardNo, U16 *int1Status, U16 *int2Status);
extern void _7296_CLR_IRQ(U16 cardNo);
extern void _7296_Software_Reset(U16 cardNo);
/*---------------------------- For 7396 -------------------------------------*/
extern U16  _7396_Initial(U16 *existCards, PCI_INFO *info);
extern U16  _7396_DI(U16 cardNo, int channelPort, U32 *inData);
extern U16  _7396_DO(U16 cardNo, int channelPort, U32 outData);
extern U16  _7396_Config_Port(U16 cardNo, int ctrlValue);
extern void _7396_Set_INT_Control(U16 cardNo, U16 ctrlValue);
extern void _7396_Timer_Start(U16 cardNo, U16 timer0Mode, U16 c0);
extern void _7396_Timer_Read(U16 cardNo, U16 *counterValue);
extern void _7396_Timer_Stop(U16 cardNo, U16 *counterValue);
extern void _7396_Cascaded_Timer(U16 cardNo, U16 c1, U16 c2);
extern void _7396_Get_IRQ_Status(U16 cardNo, U16 *int1Status, U16 *int2Status);
extern void _7396_CLR_IRQ(U16 cardNo);
extern void _7396_Software_Reset(U16 cardNo);
extern void _7396_COSIRQ_Control (U16 cardNo,int ch_no ,int A ,int B ,int C);

/****************************************************************************/
/*      Functions Declerations of PCI-7432/7433/7434                        */
/****************************************************************************/
/*---------------------------------------------------------------------------*/
extern U16  _7432_Initial(U16 *existCards, PCI_INFO *pciInfo);
extern U16  _7432_DO( U16 cardNo, U32  doData);
extern U16  _7432_DI( U16 cardNo, U32 *diData);

extern void _7432_Set_INT_Control(U16 cardNo, U16 int1Flag, U16 int2Flag);
extern void _7432_Set_INT_Polarity( U16 cardNo, U16 int1pol, U16 int2pol );
extern void _7432_Get_IRQ_Status(U16 cardNo,U16 *int1Status, U16 *int2Status);
extern void _7432_Get_IRQ_Channel(U16 cardNo, U16 *irq_no );
extern void _7432_CLR_IRQ( U16 cardNo );
extern void _7432_Software_Reset(U16 cardNo);

/*---------------------------------------------------------------------------*/
extern U16  _7433_Initial(U16 *existCards, PCI_INFO *pciInfo);
extern U16  _7433_DI_HiDW( U16 cardNo, U32  *doData );
extern U16  _7433_DI_LoDW( U16 cardNo, U32  *doData );
extern void _7433_CLR_IRQ( U16 cardNo );
extern void _7433_Get_IRQ_Status(U16 cardNo,U16 *int1Status, U16 *int2Status);
extern void _7433_Get_IRQ_Channel(U16 cardNo, U16 *irq_no );
extern void _7433_Software_Reset(U16 cardNo);

/*---------------------------------------------------------------------------*/
extern U16  _7434_Initial(U16 *existCards, PCI_INFO *pciInfo);
extern U16  _7434_DO_HiDW( U16 cardNo, U32  doData );
extern U16  _7434_DO_LoDW( U16 cardNo, U32  doData );
extern void _7434_Software_Reset(U16 cardNo);

/****************************************************************************/
/*      Functions Declerations of PCI-9111                                  */
/****************************************************************************/
extern U16  _9111_Initial(U16 *existCards, PCI_INFO *pciInfo);
extern void _9111_Software_Reset(U16 cardNo);

/*---------------------------------------------- 9111 DA -------------------*/
extern U16  _9111_DA      (U16 cardNo, I16  DAData      );

/*---------------------------------------------- Digital Input  ------------*/
extern U16  _9111_DI      (U16 cardNo, U16 *DIData      );
extern U16  _9111_DI_Channel(U16 cardNo, U16 di_ch_no , Boolean *di_data );

/*---------------------------------------------- Digital Output ------------*/
extern U16  _9111_DO      (U16 cardNo, U16  DOData      );
extern U16  _9111_DO_Channel(U16 cardNo, U16 do_ch_no , Boolean do_data );

/*---------------------------------------------- Extended DIO --------------*/
extern U16  _9111_EDI     (U16 cardNo, U16 *DIData      );
extern U16  _9111_EDO     (U16 cardNo, U16  DOData      );
extern U16  _9111_EDO_Read_Back    (U16 cardNo, U16 *DOData );
extern U16  _9111_Set_EDO_Function (U16 cardNo, U16 x   );

/*---------------------------------------------- AD Date Read Functions ----*/
extern U16  _9111_AD_Read_Data (U16 cardNo, I16 far *ADData );
extern U16  _9111_AD_Read_Data_Repeat(U16 cardNo,I16 far *ADData, U16 n );

/*---------------------------------------------- AD Functins ---------------*/
extern U16  _9111_AD_Set_Channel(U16 cardNo, U16  ADChannelNo );
extern U16  _9111_AD_Get_Channel(U16 cardNo, U16 *ADChannelNo );
extern U16  _9111_AD_Set_Range  (U16 cardNo, U16  ADRange );
extern U16  _9111_AD_Get_Range  (U16 cardNo, U16 *ADRange );
extern U16  _9111_AD_Get_Status (U16 cardNo, U16 *ADStatus);
extern U16  _9111_AD_Set_Mode   (U16 cardNo, U16  ADMode  );
extern U16  _9111_AD_Get_Mode   (U16 cardNo, U16 *ADMode  );
extern U16  _9111_INT_Set_Reg   (U16 cardNo, U16  INTC    );
extern U16  _9111_INT_Get_Reg   (U16 cardNo, U16 *INTC    );
extern U16  _9111_Reset_FIFO     ( U16 cardNo  );
extern U16  _9111_AD_Soft_Trigger(U16 cardNo );

/*---------------------------------------------- Timer Functions -----------*/
extern U16  _9111_Set_8254      (U16 cardNo, U16 ChannelNo, U8  count   );
extern U16  _9111_Get_8254      (U16 cardNo, U16 ChannelNo, U8 *count   );
extern U16  _9111_AD_Timer      (U16 cardNo, U16 c1 , U16 c2 );
extern U16  _9111_Counter_Start (U16 cardNo, U16 mode , U16 c0  );
extern U16  _9111_Counter_Read  (U16 cardNo, U16 *c0  );
extern U16  _9111_Counter_Stop  (U16 cardNo, U16 *c0  );

/*---------------------------------------------- Interrupt -----------------*/
extern void _9111_INT_Source_Control(U16 cardNo, U16 int1Ctrl , U16 int2Ctrl );
extern void _9111_CLR_IRQ (U16 cardNo);
extern void _9111_Get_IRQ_Channel(U16 cardNo, U16 *irq_no );
extern void _9111_Get_IRQ_Status(U16 cardNo, U16 *int1Status, U16 *int2Status);

/****************************************************************************/
/*      Functions Declerations of ADC_9111.C                                */
/*              Note that all these functions can be used for just ONE card */
/*              system but not multiple PCI_9111 cards.  However, the func  */
/*              deceleration can be extended for multiple cards.  Users can */
/*              refer the source code of ADC_9111 to implement the multiple */
/*              card library.                                               */
/****************************************************************************/

/*---------------------------- for AD Data Polling ------------------------*/
extern U16 _9111_AD_FFHF_Polling( U16 cardNo, I16  far *ad_data );
extern U16 _9111_AD_Aquire   ( U16 cardNo, I16  far *ad_data );
extern U16 _9111_AD_HR_Aquire( U16 cardNo, I16  far *ad_data );

/*---------------------------- for AD Interrupt Transfer Mode -------------*/
extern U16 _9111_AD_INT_Start(U16 cardNo,U16 auto_scan,U16 ad_ch_no,U16 ad_gain
                , U16 count ,  I16 far *ad_buffer , U16 c1 , U16 c2);
extern U16 _9111_AD_INT_Status( U16 cardNo, U16 *status , U16 *count  );
extern U16 _9111_AD_INT_Stop( U16 cardNo, U16 *count );

/*---------------------------- for AD FIFO Half Full Interrupt Transfer Mode-*/
extern U16 _9111_AD_FFHF_INT_Start(U16 cardNo,U16 auto_scan,U16 ad_ch_no,
                  U16 ad_gain, U16 blockNo,I16 far *ad_buffer,U16 c1,U16 c2);
extern U16 _9111_AD_FFHF_INT_Restart( U16 cardNo );
extern U16 _9111_AD_FFHF_INT_Status( U16 cardNo, U16 *status , U16 *blockNo);

/****************************************************************************/
/*      Functions Declerations of PCI-9113                                  */
/****************************************************************************/
/*---------------------------------------------- Initial, Reset ------------*/
extern U16  _9113_Initial(U16 *existCards, PCI_INFO *pciInfo);
extern void _9113_Software_Reset(U16 cardNo);

/*---------------------------------------------- AD Date Read Functions ----*/
extern U16  _9113_AD_Read_Data_MUX (U16 cardNo, U32 far *ADData );
extern U16  _9113_AD_Read_Data     (U16 cardNo, U16 far *ADData );
extern U16  _9113_AD_Read_Data_Repeat    (U16 cardNo, U16 far *ADData, U16 n );
extern U16  _9113_AD_Read_Data_Repeat_MUX(U16 cardNo, U32 far *ADData, U16 n );
/*---------------------------------------------- AD Functins ---------------*/
extern U16  _9113_AD_Set_Channel(U16 cardNo, U16  ADChannelNo );
extern U16  _9113_AD_Set_Range  (U16 cardNo, U16  ADRange );
extern U16  _9113_AD_Get_Range  (U16 cardNo, U16 *ADRange );
extern U16  _9113_AD_Set_Range2 (U16 cardNo, U16  ADRange );
extern U16  _9113_AD_Get_Range2 (U16 cardNo, U16 *ADRange );
extern U16  _9113_AD_Get_Status (U16 cardNo, U16 *ADStatus);
extern U16  _9113_AD_Set_Mode   (U16 cardNo, U16  ADMode  );
extern U16  _9113_AD_Get_Mode   (U16 cardNo, U16 *ADMode  );
extern U16  _9113_INT_Set_Reg   (U16 cardNo, U16  INTC    );
extern U16  _9113_INT_Get_Reg   (U16 cardNo, U16 *INTC    );
extern U16  _9113_Reset_FIFO    (U16 cardNo  );

extern U16  _9113_AD_Soft_Trigger(U16 cardNo );

/*---------------------------------------------- Timer Functions -----------*/
extern U16  _9113_Set_8254      (U16 cardNo, U16 ChannelNo, U8  count   );
extern U16  _9113_Get_8254      (U16 cardNo, U16 ChannelNo, U8 *count   );
extern U16  _9113_AD_Timer      (U16 cardNo, U16 c1 , U16 c2 );
extern U16  _9113_Counter_Start (U16 cardNo, U16 mode , U16 c0  );
extern U16  _9113_Counter_Read  (U16 cardNo, U16 *c0  );
extern U16  _9113_Counter_Stop  (U16 cardNo, U16 *c0  );

/*---------------------------------------------- Interrupt -----------------*/
extern void _9113_INT_Source_Control(U16 cardNo, U16 int1Ctrl , U16 int2Ctrl );
extern void _9113_CLR_IRQ (U16 cardNo);
extern void _9113_Get_IRQ_Channel(U16 cardNo, U16 *irq_no );
extern void _9113_Get_IRQ_Status(U16 cardNo, U16 *int1Status, U16 *int2Status);

/****************************************************************************/
/*      Functions Declerations of ADC_9113.C Module                         */
/*              Note that all these functions can be used for just ONE card */
/*              system but not multiple PCI_9113 cards.  However, the func  */
/*              deceleration can be extended for multiple cards.  Users can */
/*              refer the source code of ADC_9113 to implement the multiple */
/*              card library.                                               */
/****************************************************************************/

/*---------------------------- for AD Data Polling ------------------------*/
extern U16 _9113_AD_FFHF_Polling    ( U16 cardNo, U16  far *ad_data );
extern U16 _9113_AD_FFHF_Polling_MUX( U16 cardNo, U32  far *ad_data );

extern U16 _9113_AD_Aquire     ( U16 cardNo, U16  far *ad_data );
extern U16 _9113_AD_Aquire_MUX ( U16 cardNo, U32  far *ad_data );

/*---------------------------- for AD EOC Interrupt Transfer Mode -----------*/
extern U16 _9113_AD_INT_Start(U16 cardNo,U16 auto_scan,U16 ad_ch_no,U16 ad_gain
                , U16 count ,  U32 far *ad_buffer , U16 c1 , U16 c2);
extern U16 _9113_AD_INT_Status( U16 cardNo, U16 *status , U16 *count  );
extern U16 _9113_AD_INT_Stop( U16 cardNo, U16 *count );

/*---------------------------- for AD FIFO Half Full Interrupt Transfer Mode-*/
extern U16 _9113_AD_FFHF_INT_Start(U16 cardNo,U16 auto_scan,U16 ad_ch_no,
                  U16 ad_gain, U16 blockNo,U32 far *ad_buffer,U16 c1,U16 c2);
extern U16 _9113_AD_FFHF_INT_Restart( U16 cardNo );
extern U16 _9113_AD_FFHF_INT_Status( U16 cardNo, U16 *status , U16 *blockNo);


/****************************************************************************/
/*      Functions Declerations of PCI-9118                                  */
/****************************************************************************/
/*---------------------------------------------- Initialization ------------*/
extern  int _9118_Initial(int card_number, int *base_address, int *irq_no );
extern  int _9118_Switch_Card_No( int card_number );

/*---------------------------------------------- Digital Input  ------------*/
extern  int _9118_DI(unsigned int far *data );
extern  int _9118_DI_Channel( int di_ch_no , unsigned int far *data );

/*---------------------------------------------- Digital Output ------------*/
extern  int _9118_DO(unsigned int data );

/*---------------------------------------------- DA  -----------------------*/
extern  int _9118_DA( int ch_no, unsigned int data );

/*---------------------------- AFIFO function ------------------------*/
extern  int _9118_AD_Reset_AFIFO();
extern  int _9118_AD_Bgnset_AFIFO();
extern  int _9118_AD_Endset_AFIFO();

/*---------------------------- DFIFO function ------------------------*/
extern  int _9118_AD_Reset_DFIFO();

/*---------------------------- AD Burst Number -----------------------*/
extern  int _9118_AD_Set_Burst_No(int BurstNo);

/*---------------------------- Interrupt function ------------------------*/
extern  int _9118_INT_Set_CtrlReg(int CtrlVal);

/*---------- General A/D function ---------------------------------------*/
extern  int _9118_AD_Set_GainChn( int ch,int gain );
extern  int _9118_AD_Set_Scan(int start,int end,int gain );
extern  int _9118_AD_Soft_Trig  ( void );

/*---------------------------- A/D control register ------------------*/
extern  int _9118_AD_Set_Unip(int Unip);
extern  int _9118_AD_Set_Diff(int Diff);
extern  int _9118_AD_Set_SoftG(int SoftG);
extern  int _9118_AD_Set_ExtG(int ExtG);
extern  int _9118_AD_Set_ExtM(int ExtM);
extern  int _9118_AD_Set_TmrTr(int TmrTr);
extern  int _9118_AD_Set_Int(int Int);
extern  int _9118_AD_Set_Dma(int Dma);
extern  int _9118_AD_Set_CtrlReg(int CtrlVal);

/*---------------------------- A/D function register ------------------*/
extern  int _9118_AD_Set_PDTrg(int PDTrg);
extern  int _9118_AD_Set_PETrg(int PETrg);
extern  int _9118_AD_Set_BSSH(int BSSH);
extern  int _9118_AD_Set_BM(int BM);
extern  int _9118_AD_Set_BS(int BS);
extern  int _9118_AD_Set_PM(int PM);
extern  int _9118_AD_Set_AM(int AM);
extern  int _9118_AD_Set_Start(int Start);
extern  int _9118_AD_Set_FuncReg(int FuncVal);

/*---------- Software Trigger to Conversion A/D Data --------------------*/
extern  int _9118_AD_Aquire     ( int far *ad_data );

/*----  One Shot Timer Pacer trigger to Conversion A/D Data (DMA)  ----*/
extern  int _9118_AD_DMA_Start(int clk_src, unsigned int count , unsigned long *ad_buffer , int c1 , int c2 );
extern  int _9118_AD_DMA_Status( int *status , int *count );
extern  int _9118_AD_DMA_Stop( int *count, int *start_idx);

/*----  One Shot Timer Pacer trigger to Conversion A/D Data (Interrupt) ----*/
extern  int _9118_AD_INT_Start(int count , unsigned long *ad_buffer, int c1, int c2 );
extern  int _9118_AD_INT_Status(int *status, int *count  );
extern  int _9118_AD_INT_Stop(int *count );

/*----  Continue Timer Pacer trigger to Conversion A/D Data (DMA)  ----*/
extern  int _9118_ContDmaStart(int clk_src, unsigned int count , unsigned long *doubleBuf, int c1 , int c2 );
extern  int _9118_CheckHalfReady(int *halfReady, int *stop_flag);
extern  int _9118_DblBufferTransfer(unsigned short *userBuffer);
extern  int _9118_GetOverrunStatus(int *overrunCount);
extern  int _9118_ContDmaStop(unsigned int *count);

/*---------------------------------------------- Timer ---------------------*/
extern  int _9118_AD_Timer( int c1 , int c2 );
extern  int _9118_TIMER_Start( int timer_mode, unsigned int c0 );
extern  int _9118_TIMER_Read( unsigned int *counter_value );
extern  int _9118_TIMER_Stop( unsigned int *counter_value );


/****************************************************************************/
/*      Functions Declerations of PCI-9114                                  */
/****************************************************************************/
/*---------------------------------------------- Initial, Reset ------------*/
extern U16  _9114_Initial(U16 *existCards, PCI_INFO *pciInfo);
extern void _9114_Software_Reset(U16 cardNo);

/*---------------------------------------------- Digital I/O Functions ----*/
extern U16  _9114_DO  (U16 cardNo, U16      ADData );
extern U16  _9114_DI  (U16 cardNo, U16 far *ADData );

/*---------------------------------------------- AD Date Read Functions ----*/
extern U16  _9114_AD_Read_Data_MUX (U16 cardNo, U32 far *ADData );
extern U16  _9114_AD_Read_Data     (U16 cardNo, U16 far *ADData );
extern U16  _9114_AD_Read_Data_Repeat    (U16 cardNo, U16 far *ADData, U16 n );
extern U16  _9114_AD_Read_Data_Repeat_MUX(U16 cardNo, U32 far *ADData, U16 n );
/*---------------------------------------------- AD Functins ---------------*/
extern U16  _9114_AD_Set_Channel(U16 cardNo, U16  ADChannelNo );
extern U16  _9114_AD_Get_Channel(U16 cardNo, U16 *ADChannelNo );
extern U16  _9114_AD_Set_Range  (U16 cardNo, U16  ADRange );
extern U16  _9114_AD_Get_Range  (U16 cardNo, U16 *ADRange );
extern U16  _9114_AD_Set_Range2 (U16 cardNo, U16  ADRange );
extern U16  _9114_AD_Get_Range2 (U16 cardNo, U16 *ADRange );
extern U16  _9114_AD_Get_Status (U16 cardNo, U16 *ADStatus);
extern U16  _9114_AD_Set_Mode   (U16 cardNo, U16  ADMode  );
extern U16  _9114_AD_Get_Mode   (U16 cardNo, U16 *ADMode  );
extern U16  _9114_INT_Set_Reg   (U16 cardNo, U16  INTC    );
extern U16  _9114_INT_Get_Reg   (U16 cardNo, U16 *INTC    );
extern U16  _9114_Reset_FIFO    (U16 cardNo  );

extern U16  _9114_AD_Soft_Trigger(U16 cardNo );

/*---------------------------------------------- Timer Functions -----------*/
extern U16  _9114_Set_8254      (U16 cardNo, U16 ChannelNo, U8  count   );
extern U16  _9114_Get_8254      (U16 cardNo, U16 ChannelNo, U8 *count   );
extern U16  _9114_AD_Timer      (U16 cardNo, U16 c1 , U16 c2 );
extern U16  _9114_Counter_Start (U16 cardNo, U16 mode , U16 c0  );
extern U16  _9114_Counter_Read  (U16 cardNo, U16 *c0  );
extern U16  _9114_Counter_Stop  (U16 cardNo, U16 *c0  );

/*---------------------------------------------- Interrupt -----------------*/
extern void _9114_INT_Source_Control(U16 cardNo, U16 int1Ctrl , U16 int2Ctrl );
extern void _9114_CLR_IRQ1 (U16 cardNo);
extern void _9114_CLR_IRQ2 (U16 cardNo);
extern void _9114_Get_IRQ_Channel(U16 cardNo, U16 *irq_no );
extern void _9114_Get_IRQ_Status(U16 cardNo, U16 *int1Status, U16 *int2Status);

/****************************************************************************/
/*      Functions Declerations of ADC_9114.C Module                         */
/*              Note that all these functions can be used for just ONE card */
/*              system but not multiple PCI_9114 cards.  However, the func  */
/*              deceleration can be extended for multiple cards.  Users can */
/*              refer the source code of ADC_9114 to implement the multiple */
/*              card library.                                               */
/****************************************************************************/

/*---------------------------- for AD Data Polling ------------------------*/
extern U16 _9114_AD_FFHF_Polling    ( U16 cardNo, I16  far *ad_data );
extern U16 _9114_AD_FFHF_Polling_MUX( U16 cardNo, U32  far *ad_data );

extern U16 _9114_AD_Aquire     ( U16 cardNo, I16  far *ad_data );
extern U16 _9114_AD_Aquire_MUX ( U16 cardNo, U32  far *ad_data );

/*---------------------------- for AD EOC Interrupt Transfer Mode -----------*/
extern U16 _9114_AD_INT_Start(U16 cardNo,U16 auto_scan,U16 ad_ch_no,U16 ad_gain
                , U16 count ,  U32 far *ad_buffer , U16 c1 , U16 c2);
extern U16 _9114_AD_INT_Status( U16 cardNo, U16 *status , U16 *count  );
extern U16 _9114_AD_INT_Stop( U16 cardNo, U16 *count );

/*---------------------------- for AD FIFO Half Full Interrupt Transfer Mode-*/
extern U16 _9114_AD_FFHF_INT_Start(U16 cardNo,U16 auto_scan,U16 ad_ch_no,
                  U16 ad_gain, U16 blockNo,U32 far *ad_buffer,U16 c1,U16 c2);
extern U16 _9114_AD_FFHF_INT_Restart( U16 cardNo );
extern U16 _9114_AD_FFHF_INT_Status( U16 cardNo, U16 *status , U16 *blockNo);


#ifdef __cplusplus
}
#endif

#endif
