#ifndef VIDEO_C    /* to assert that only one occurrence is included */
    #define VIDEO_C
/*;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  Copyright (c) 1995-1996, ADLink Technology Inc.  All rights reserved.  ;;
;;									    ;;
;;	Module	: video.h    text mode basic video  function		    ;;
;;	Date	: 8/8/1996						    ;;
;;	Rev.	: 1.10							    ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;*/
/*----- INCLUDE -----------------------------------------------------------*/
#include    <stdio.h>
#include    <string.h>
#include    <dos.h>
#include    "std.h"
#include    "video.h"


/*----- FUNCTION ----------------------------------------------------------*/
std_Byte video_GetMode(void)
{
    union REGS	r;

    r.h.ah = 0x0f;
    int86(0x10, &r, &r);
    return (r.h.al);
}

/*-------------------------------------------------------------------------*/
void video_Gotoxy(int x, int y)     /* set cursor on at position (row,col) */
{
   union REGS  r;

   r.h.ah = 0x02;     /* set cursor position */
   r.h.dh = x;	      /* row */
   r.h.dl = y;	      /* column */
   r.h.bh = 0;	      /* page 0 */
   int86(0x10, &r, &r);
}
/*-------------------------------------------------------------------------*/
void video_CursorOn(void)
{
   std_Byte	mode;
   union REGS	r;

   mode = video_GetMode();
   r.h.ah = 0x01;		      /* set cursor type */
   r.h.ch= (mode == 7 ? 11: 6);
   r.h.cl= (mode == 7 ? 12: 7);
   int86(0x10, &r, &r);
}
/*-------------------------------------------------------------------------*/
void video_CursorOff(void)
{
    union REGS	r;

    r.h.ah = 0x01;		       /* set cursor type */
    r.h.ch = 0x0f;
    r.h.cl = 0x00;
    int86(0x10, &r, &r);
}
/*-------------------------------------------------------------------------*/
void video_PutChar( char a_byte, int attr)
{
    union REGS	r;

    r.h.ah = 0x09;
    r.h.bh = 0;
    r.x.cx = 1;
    r.h.bl = attr;
    r.h.al = a_byte;
    int86(0x10, &r, &r);
}
/*-------------------------------------------------------------------------*/
void video_PutStr(int x, int y, char *str, int attr)
{
   while(*str)
   {
      video_Gotoxy(x,y++);
      video_PutChar(*str++, attr);
   }
}
/*-------------------------------------------------------------------------*/
void video_CenterPutStr(int x, char *str, int attr)
{
    int     y;

    y = (80 - strlen(str)) / 2;
    video_PutStr(x, y, str, attr);

}
/*-------------------------------------------------------------------------*/
void video_ClearBox(int x1, int y1, int x2, int y2, int attr)
{
    union REGS	r;
    int 	i;

    r.h.bh = 0;
    r.h.bl = attr;
    r.x.cx = y2-y1+1;

    for (i = x1; i <= x2; i++) {
	r.h.ah = 0x09;
	r.h.al = 0x20;
	video_Gotoxy(i, y1);
	int86(0x10, &r, &r);
    }
}
/*-------------------------------------------------------------------------*/
void video_Scroll(int x1, int y1, int x2, int y2, int attr, int control)
{
    union REGS	r;

    r.h.ah = control;			  /* set cursor type */
    r.h.al = 1;
    r.h.ch = x1;
    r.h.cl = y1;
    r.h.dh = x2;
    r.h.dl = y2;
    r.h.bh = attr;
    int86(0x10, &r, &r);
}
/*-------------------------------------------------------------------------*/
void video_Initial(void)
{
    union REGS	r;

    video_Gotoxy(0, 0);
    r.h.ah = 0x09;
/*  r.h.al = 0xb1;*/
    r.h.al = 0x20;
    r.h.bh = 0;
    video_Mode = video_GetMode();
/*  r.h.bl = (video_Mode == 7 ? 0x07 : 0x17);*/
    r.h.bl = 0x07;
    r.x.cx = 25 * 80;
    int86(0x10, &r, &r);
}
/*-------------------------------------------------------------------------*/
void video_Box(int type, int x1, int y1, int x2, int y2, int attr)
{
    int i;
    char   *xy11, *xy12, *xy21, *xy22, *u, *d, *l, *rb;

   video_ClearBox(x1, y1, x2, y2, attr);

   switch (type)
   {
       case VIDEO_NOBORDER:
	     xy11 = ""; xy12 = ""; xy21 = ""; xy22 = "";
	     u	  = ""; d    = ""; l    = ""; rb   = "";
	     break;

       case VIDEO_GRAYLEVEL:
	     xy11 = ""; xy12 = ""; xy21 = ""; xy22 = "";
	     u	  = ""; d    = ""; l    = ""; rb   = "";
	     break;

       case VIDEO_SINGLE:
	     xy11 = ""; xy12 = ""; xy21 = ""; xy22 = "";
	     u	  = ""; d    = ""; l    = ""; rb   = "";
	     break;
       case VIDEO_DOUBLE:
	     xy11 = ""; xy12 = ""; xy21 = ""; xy22 = "";
	     u	  = ""; d    = ""; l    = ""; rb   = "";
	     break;
       default:
	     xy11 = ""; xy12 = ""; xy21 = ""; xy22 = "";
	     u	  = ""; d    = ""; l    = ""; rb   = "";
	     break;
   };

   for (i = y1 ; i < y2; i++)
   {
/*     video_PutStr(x2+1, i+2,"" , 0x17);*/
       video_PutStr(x1, i, u, attr);
       video_PutStr(x2, i, d, attr);

   }
   for (i = x1 ; i <= x2; i++)
   {

/*     video_PutStr(i+1, y2+1 , "", 0x17);*/
       video_PutStr(i, y1 , l, attr);
       video_PutStr(i, y2 , rb, attr);
   }

   video_PutStr(x1, y1, xy11, attr);
   video_PutStr(x1, y2, xy12, attr);
   video_PutStr(x2, y1, xy21, attr);
   video_PutStr(x2, y2, xy22, attr);
}
/*-------------------------------------------------------------------------*/
void video_PageScroll(int x1, int y1, int x2, int y2, int attr, int control)
{
    union REGS	r;
    r.h.ah = control;			  /* set cursor type */
    r.h.al = 1;
    r.h.ch = x1;
    r.h.cl = y1;
    r.h.dh = x2;
    r.h.dl = y2;
    r.h.bh = attr;
    int86(0x10, &r, &r);
}
/*-------------------------------------------------------------------------*/
/*-------------------------------------------------------------------------*/
/*-------------------------------------------------------------------------*/
#endif	/* end of #ifdef VIDEO.C */
